@@ -14,7 +14,7 @@ from appdirs import user_cache_dir
 
 from .click_common import DeviceGroup, GlobalContextObject, LiteralParamType, command
 from .device import Device
-from .exceptions import DeviceException
+from .exceptions import DeviceException, DeviceInfoUnavailableException
 from .vacuumcontainers import (
     CarpetModeStatus,
     CleaningDetails,
@@ -61,6 +61,15 @@ class FanspeedV2(enum.Enum):
     Gentle = 105
 
 
+class FanspeedE2(enum.Enum):
+    # Original names from the app: Gentle, Silent, Standard, Strong, Max
+    Gentle = 41
+    Silent = 50
+    Standard = 68
+    Medium = 79
+    Turbo = 100
+
+
 ROCKROBO_V1 = "rockrobo.vacuum.v1"
 
 
@@ -445,7 +454,7 @@ class Vacuum(Device):
         try:
             info = self.info()
             self.model = info.model
-        except TypeError:
+        except (TypeError, DeviceInfoUnavailableException):
             # cloud-blocked vacuums will not return proper payloads
             self._fanspeeds = FanspeedV1
             self.model = ROCKROBO_V1
@@ -463,6 +472,8 @@ class Vacuum(Device):
                 self._fanspeeds = FanspeedV2
             else:
                 self._fanspeeds = FanspeedV1
+        elif info.model == "roborock.vacuum.e2":
+            self._fanspeeds = FanspeedE2
         else:
             self._fanspeeds = FanspeedV2
 
