@@ -123,6 +123,7 @@ def status(vac: miio.Vacuum):
     # click.echo("DND enabled: %s" % res.dnd)
     # click.echo("Map present: %s" % res.map)
     # click.echo("in_cleaning: %s" % res.in_cleaning)
+    click.echo("Water box attached: %s" % res.is_water_box_attached)
 
 
 @cli.command()
@@ -230,17 +231,17 @@ def manual(vac: miio.Vacuum):
     # if not vac.manual_mode and command :
 
 
-@manual.command()  # noqa: F811  # redefinition of start
+@manual.command()
 @pass_dev
-def start(vac: miio.Vacuum):
+def start(vac: miio.Vacuum):  # noqa: F811  # redef of start
     """Activate the manual mode."""
     click.echo("Activating manual controls")
     return vac.manual_start()
 
 
-@manual.command()  # noqa: F811  # redefinition of stop
+@manual.command()
 @pass_dev
-def stop(vac: miio.Vacuum):
+def stop(vac: miio.Vacuum):  # noqa: F811  # redef of stop
     """Deactivate the manual mode."""
     click.echo("Deactivating manual controls")
     return vac.manual_stop()
