@@ -3,7 +3,10 @@ from datetime import datetime, time, timedelta
 from enum import IntEnum
 from typing import Any, Dict, List
 
-from .utils import deprecated, pretty_seconds, pretty_time
+from croniter import croniter
+from pytz import timezone
+
+from .utils import pretty_seconds, pretty_time
 
 
 def pretty_area(x: float) -> float:
@@ -57,6 +60,15 @@ class VacuumStatus:
         # "dnd_enabled":0,"begin_time":1534333389,"clean_time":21,
         # "clean_area":202500,"clean_trigger":2,"back_trigger":0,
         # "completed":0,"clean_strategy":1}
+
+        # Example of S6 in the segment cleaning mode
+        # new items: in_fresh_state, water_box_status, lab_status, map_status, lock_status
+        #
+        # [{'msg_ver': 2, 'msg_seq': 28, 'state': 18, 'battery': 95,
+        # 'clean_time': 606, 'clean_area': 8115000, 'error_code': 0,
+        # 'map_present': 1, 'in_cleaning': 3, 'in_returning': 0,
+        # 'in_fresh_state': 0, 'lab_status': 1, 'water_box_status': 0,
+        # 'fan_power': 102, 'dnd_enabled': 0, 'map_status': 3, 'lock_status': 0}]
         self.data = data
 
     @property
@@ -127,30 +139,21 @@ class VacuumStatus:
         """Cleaned area in m2."""
         return pretty_area(self.data["clean_area"])
 
-    @property
-    @deprecated("Use vacuum's dnd_status() instead, which is more accurate")
-    def dnd(self) -> bool:
-        """DnD status. Use :func:`vacuum.dnd_status` instead of this."""
-        return bool(self.data["dnd_enabled"])
-
     @property
     def map(self) -> bool:
         """Map token."""
         return bool(self.data["map_present"])
 
-    @property
-    @deprecated("See is_on")
-    def in_cleaning(self) -> bool:
-        """True if currently cleaning. Please use :func:`is_on` instead of this."""
-        return self.is_on
-        # we are not using in_cleaning as it does not seem to work properly.
-        # return bool(self.data["in_cleaning"])
-
     @property
     def in_zone_cleaning(self) -> bool:
         """Return True if the vacuum is in zone cleaning mode."""
         return self.data["in_cleaning"] == 2
 
+    @property
+    def in_segment_cleaning(self) -> bool:
+        """Return True if the vacuum is in segment cleaning mode."""
+        return self.data["in_cleaning"] == 3
+
     @property
     def is_paused(self) -> bool:
         """Return True if vacuum is paused."""
@@ -158,15 +161,20 @@ class VacuumStatus:
 
     @property
     def is_on(self) -> bool:
-        """True if device is currently cleaning (either automatic, manual,
-         spot, or zone)."""
+        """True if device is currently cleaning in any mode."""
         return (
             self.state_code == 5
             or self.state_code == 7
             or self.state_code == 11
             or self.state_code == 17
+            or self.state_code == 18
         )
 
+    @property
+    def is_water_box_attached(self) -> bool:
+        """Return True is water box is installed."""
+        return "water_box_status" in self.data and self.data["water_box_status"] == 1
+
     @property
     def got_error(self) -> bool:
         """True if an error has occured."""
@@ -396,12 +404,13 @@ class Timer:
     The timers are accessed using an integer ID, which is based on the unix
     timestamp of the creation time."""
 
-    def __init__(self, data: List[Any]) -> None:
+    def __init__(self, data: List[Any], timezone: str) -> None:
         # id / timestamp, enabled, ['<cron string>', ['command', 'params']
         # [['1488667794112', 'off', ['49 22 * * 6', ['start_clean', '']]],
         #  ['1488667777661', 'off', ['49 21 * * 3,4,5,6', ['start_clean', '']]
         # ],
         self.data = data
+        self.timezone = timezone
 
     @property
     def id(self) -> int:
@@ -429,6 +438,14 @@ class Timer:
         Note, this seems to be always 'start'."""
         return str(self.data[2][1])
 
+    @property
+    def next_schedule(self) -> datetime:
+        """Next schedule for the timer."""
+        local_tz = timezone(self.timezone)
+        cron = croniter(self.cron, start_time=local_tz.localize(datetime.now()))
+
+        return cron.get_next(ret_type=datetime)
+
     def __repr__(self) -> str:
         return "<Timer %s: %s - enabled: %s - cron: %s>" % (
             self.id,
